#!/bin/bash
##
## Pipeline script for checking status of a HiSeq sequencing run.
## 
## Environment variables that should be defined before calling this script
##  -AllRunArchives: White-space separated list of locations to search for sequencing data
##  -BARCODE: Barcode of the flow cell that we want to find information for
## 
## The output is a number of key-value pairs. All values may not be present.
##  -RunArchive: The path to the data folder for the flow cell
##  -Config: Date and time the 'Config' folder was last modified
##  -RunParameters: Date and time the 'runParameters.xml' file was last modified
##  -BclCount: Number of files ending with '.bcl'
##  -LaneCount: Value from <FlowcellLayout LaneCount> tag in RunInfo.xml
##  -SurfaceCount: Value from <FlowcellLayout SurfaceCount> tag in RunInfo.xml
##  -SwathCount: Value from <FlowcellLayout SwathCount> tag in RunInfo.xml
##  -TileCount: Value from <FlowcellLayout TileCount> tag in RunInfo.xml
##  -Read1: Value from <Read1> tag in runParameters.xml
##  -Read2: Value from <Read2> tag in runParameters.xml
##  -IndexRead1: Value from <IndexRead1> tag in runParameters.xml
##  -IndexRead2: Value from <IndexRead2> tag in runParameters.xml
##  -RTAComplete: Date and time the 'RTAComplete.txt' was last modified
##  -HiSeqSerial: Value from <ScannerID> tag in runParameters.xml


# Format string for file dates/times
DATE_FORMAT="%Y%m%d %H%M%S"

# Try to find a folder inside run-archive that has the barcode in the name
# The folder may not yet exist so a missing folder is not an error
DATA_FOLDER=`find ${AllRunArchives} -maxdepth 2 -iname "*${BARCODE}*" -type d -print 2> /dev/null || true`

# Fail if more than one folder is found
readarray -t lines <<< "${DATA_FOLDER}"
if [ ! ${#lines[@]} -eq 1 ]; then
	echo "Found ${#lines[@]} data folders for flow cell ${BARCODE}" 1>&2
	echo ${DATA_FOLDER} 1>&2
	exit 1
fi

echo RunArchive: ${DATA_FOLDER}
# Config folder is created immediately when starting the HiSeq
# We use the date of this folder to set the start date of the job
if [ -d "${DATA_FOLDER}/Config" ]; then
	echo "Config: `date +"${DATE_FORMAT}" -r "${DATA_FOLDER}/Config"`"
fi

# runParameters.xml is created after clustering
# We extract information about number of reads and lanes
# and compare that to the number of *.bgzf.bci files we can find
# This gives an estimate of the current sequencing cycle and we can
# use this for progress reporting
RUN_PARAMETERS=${DATA_FOLDER}/runParameters.xml
if [ -f "${RUN_PARAMETERS}" ]; then
	echo "RunParameters: `date +"${DATE_FORMAT}" -r "${RUN_PARAMETERS}"`"
	echo "Read1: `grep '<Read1>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "Read2: `grep '<Read2>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "IndexRead1: `grep '<IndexRead1>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "IndexRead2: `grep '<IndexRead2>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "HiSeqSerial: `grep '<ScannerID>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
fi

# Count number of BCL files which gives us information about
# the progress of the sequencing
BCL_FOLDER=${DATA_FOLDER}/Data/Intensities/BaseCalls
if [ -d "${BCL_FOLDER}" ]; then
	echo "BclCount: `find "${BCL_FOLDER}" -type f -name *.bcl | wc -l`"
fi

# RunInfo.xml contains information about the layout of the flowcell
# which we need to be able to compare the number of BCL files
RUN_INFO=${DATA_FOLDER}/RunInfo.xml
if [ -f "${RUN_PARAMETERS}" ]; then
	echo "LaneCount: `grep -o 'LaneCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "SurfaceCount: `grep -o 'SurfaceCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "SwathCount: `grep -o 'SwathCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "TileCount: `grep -o 'TileCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
fi



# RTAComplete.txt is created when everything is complete
# This becomes the end date of the job and should trigger
# Reggie to start file checks and secondary analysis
if [ -f "${DATA_FOLDER}/RTAComplete.txt" ]; then
	echo "RTAComplete: `date +"${DATE_FORMAT}" -r "${DATA_FOLDER}/RTAComplete.txt"`"
fi
