#!/bin/bash
##
## Pipeline script for checking status of a NovaSeq sequencing run.
## 
## Environment variables that should be defined before calling this script
##  -AllRunArchives: White-space separated list of locations to search for sequencing data
##  -BARCODE: Barcode of the flow cell that we want to find information for
## 
## The output is a number of key-value pairs. All values may not be present.
##  -RunArchive: The path to the data folder for the flow cell
##  -Config: Date and time the 'Config' folder was last modified
##  -RunParameters: Date and time the 'RunParameters.xml' file was last modified
##  -Read1: Value from <Read1NumberOfCycles> tag in RunParameters.xml
##  -Read2: Value from <Read2NumberOfCycles> tag in RunParameters.xml
##  -Index1Read: Value from <IndexRead1NumberOfCycles> tag in RunParameters.xml
##  -Index2Read: Value from <IndexRead2NumberOfCycles> tag in RunParameters.xml
##  -NovaSeqSerial: Value from <InstrumentName> tag in RunParameters.xml
##  -CbclCount: Number of files ending with '.cbcl'
##  -LaneCount: Value from the LaneCount attribute in FlowcellLayout tag in RunInfo.xml
##  -SurfaceCount: Value from the SurfaceCount attribute in FlowcellLayout tag in RunInfo.xml
##  -SwathCount: Value from the SwathCount attribute in FlowcellLayout tag in RunInfo.xml
##  -TileCount: Value from the TileCount attribute in FlowcellLayout tag in RunInfo.xml
##  -RTAComplete: Date and time the 'RTAComplete.txt' was last modified


# Format string for file dates/times
DATE_FORMAT="%Y%m%d %H%M%S"

# Try to find a folder inside run-archive that has the barcode in the name
# The folder may not yet exist so a missing folder is not an error
DATA_FOLDER=`find ${AllRunArchives} -maxdepth 2 -iname "*${BARCODE}*" -type d -print 2> /dev/null || true`

# Fail if more than one folder is found
readarray -t lines <<< "${DATA_FOLDER}"
if [ ! ${#lines[@]} -eq 1 ]; then
	echo "Found ${#lines[@]} data folders for flow cell ${BARCODE}" 1>&2
	echo ${DATA_FOLDER} 1>&2
	exit 1
fi

echo RunArchive: ${DATA_FOLDER}
# Config folder is created immediately when starting the NovaSeq
# We use the date of this folder to set the start date of the job
if [ -d "${DATA_FOLDER}/Config" ]; then
	echo "Config: `date +"${DATE_FORMAT}" -r "${DATA_FOLDER}/Config"`"
fi

# RunParameters.xml is created after clustering
# We extract information about number of reads and lanes
# and compare that to the number of *.cbcl files we can find
# This gives an estimate of the current sequencing cycle and we can
# use this for progress reporting
RUN_PARAMETERS=${DATA_FOLDER}/RunParameters.xml
if [ -f "${RUN_PARAMETERS}" ]; then
	echo "RunParameters: `date +"${DATE_FORMAT}" -r "${RUN_PARAMETERS}"`"
	echo "Read1: `grep '<Read1NumberOfCycles>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "Read2: `grep '<Read2NumberOfCycles>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "Index1Read: `grep '<IndexRead1NumberOfCycles>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "Index2Read: `grep '<IndexRead2NumberOfCycles>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "NovaSeqSerial: `grep '<InstrumentName>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
	echo "FlowCellMode: `grep '<FlowCellMode>' "${RUN_PARAMETERS}" | cut -d '>' -f 2 | cut -d '<' -f 1`"
fi

# Count number of BCL files which gives us information about
# the progress of the sequencing
CBCL_FOLDER=${DATA_FOLDER}/Data/Intensities/BaseCalls
if [ -d "${CBCL_FOLDER}" ]; then
	echo "CbclCount: `find "${CBCL_FOLDER}" -type f -name *.cbcl | wc -l`"
fi


# RunInfo.xml contains information about the layout of the flowcell
# which we need to be able to compare the number of *.cbcl files
RUN_INFO=${DATA_FOLDER}/RunInfo.xml
if [ -f "${RUN_INFO}" ]; then
	echo "LaneCount: `grep -o 'LaneCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "SurfaceCount: `grep -o 'SurfaceCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "SwathCount: `grep -o 'SwathCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "TileCount: `grep -o 'TileCount="[^"]*"' "${RUN_INFO}" | cut -d '"' -f 2`"
	echo "TileTags: `grep '<Tile>' "${RUN_INFO}" | wc -l`"
	RUN_INFO_DATE=`grep '<Date>' "${RUN_INFO}" | cut -d '>' -f 2 | cut -d '<' -f 1`
	echo "RunInfoDate: `date -d "${RUN_INFO_DATE}" +"${DATE_FORMAT}"`"
fi


# RTAComplete.txt is created when everything is complete
# This becomes the end date of the job and should trigger
# Reggie to start file checks and secondary analysis
if [ -f "${DATA_FOLDER}/RTAComplete.txt" ]; then
	echo "RTAComplete: `date +"${DATE_FORMAT}" -r "${DATA_FOLDER}/RTAComplete.txt"`"
fi