# $Id $
#
# Useful utility functions that can be used by other scipts.
# Include this file in other scripts with:
# 
# source ./reggie-utils.sh
#

# Enable output of script to stderr if debugging
if [ "${JOB_DEBUG}" ]; then
	set -x;
fi

# Use 1 thread/core but not more than slots assigned by the queue system
export NumThreads=`nproc`
if [ "${NSLOTS}" ]; then
	NumThreads=$(( ${NSLOTS} < ${NumThreads} ? ${NSLOTS} : ${NumThreads} ))
fi


# Report progress to the $WD/progress file
# Two parameters are required:
#  $1: The progress in percent
#  $2: A message to display in the progress bar 
rg_progress()
{
	local percent=$1
	local msg=$2
	echo "${percent} ${msg}" > ${WD}/progress
}

# Exit the script. An exit code is required and an optional
# message is printed to stderr
#  $1: The exit code
#  $2: A message that is echo-ed to stderr (optional)
rg_exit()
{
	local exitCode=$1
	local msg=$2
	if [ "$msg" ]; then
		echo "${msg}" 1>&2
	fi
	exit ${exitCode}
}

# Check if one or more variables have been set or not. Exit with an error message if not.
# Note that parameters should be name of the environment variables to test,
# NOT the values of the variables.
rg_var_isset()
{
	for var in $@ ; do
		if [ ! "${!var}" ]; then
			rg_exit 1 "Variable '${var}' has no value"
		elif [ "${JOB_DEBUG}" ]; then 
			echo "Variable '${var}-->${!var}' is set"
		fi
	done
}

# Check if one or more variables have been set to a value that points to an
# existing directory. Exit with an error message if not.
# Note that parameters should be name of the environment variables to test,
# NOT directory paths.
rg_var_isdir()
{
	for dir in $@ ; do
		if [ ! "${!dir}" ]; then
			rg_exit 1 "Variable '${dir}' has no value"
		elif [ ! -d "${!dir}" ]; then
			rg_exit 1 "Directory '${dir}-->${!dir}' doesn't exists"
		elif [ "${JOB_DEBUG}" ]; then
			echo "Directory '${dir}-->${!dir}' exists"
		fi
	done
}

# Check if one or more variables have been set to a value that points to an
# existing file. Exit with an error message if not.
# Note that parameters should be name of environment variables to test,
# NOT file paths.
rg_var_isfile()
{
	for file in $@ ; do
		if [ ! "${!file}" ]; then
			rg_exit 1 "Variable '${file}' has no value"
		elif [ ! -f "${!file}" ]; then
			rg_exit 1 "File '${file}-->${!file}' doesn't exists"
		elif [ "${JOB_DEBUG}" ]; then
			echo "File '${file}-->${!file}' exists"
		fi
	done
}

# Check if one ore more directory exists. Exit with an error message if not.
rg_dir_exists()
{
	for dir in $@ ; do
		if [ ! -d "${dir}" ]; then
			rg_exit 1 "Directory '${dir}' doesn't exists"
		elif [ "${JOB_DEBUG}" ]; then
			echo "Directory '${dir}' exists"
		fi
	done
}

# Check if one or more file exists. Exit with an error message if not.
rg_file_exists()
{
	for file in $@ ; do
		if [ ! -f "${file}" ]; then
			rg_exit 1 "File '${file}' doesn't exists"
		elif [ "${JOB_DEBUG}" ]; then
			echo "File '${file}' exists"
		fi
	done
}
