#!/bin/bash
##
## Pipeline script for the StringTie analysis. It requries an 'alignment.bam' file and
## output results in a sub-directory.
##
## Environment variables that should be defined (in job.sh) before calling this script
##  -BamFolder: Path to folder where alignment.bam is found (results will also be saved here)
##  -BamName: Base part of alignment BAM file (eg. alignment)
##  -StringTieFolder: Folder for output. Will be created or cleared from existing files
##  -ExternalStringTieName: External name of the StringTie item that is being created
##  -AvgReadLength: Average read length used in the sequencing
##  -STRINGTIE: Path to StringTie program
##  -PREPDE: Path to PrepDE program
##  -GTF: Path to reference GTF file
##  -StringTieOptions: Other options for the StringTie program
##  -TMPDIR: Path to a local temporary working directory
##

set -e

## Import utility functions
source ./reggie-utils.sh

## Verify settings in options
rg_var_isdir "BamFolder" "TMPDIR" "WD"
rg_var_isfile "STRINGTIE" "PREPDE" "GTF"
rg_var_isset "BamName" "ExternalStringTieName" "AvgReadLength" "StringTieFolder"
rg_file_exists "${BamFolder}/${BamName}.bam" "${BamFolder}/${BamName}.bai"

## Move to the temporary working directory
cd ${TMPDIR}
mkdir -p bam
mkdir -p stringtie
mkdir -p done

## Copy BAM file to local working directory
if [ ! -f "done/copy.done" ]; then
	rg_progress 10 "Copying BAM file"
	cp ${BamFolder}/${BamName}.bam bam/alignment.bam
	cp ${BamFolder}/${BamName}.bai bam/alignment.bai
	touch "done/copy.done"
fi

## Run StringTie
if [ ! -f "done/stringtie.done" ]; then
	rg_progress 20 "Running StringTie (${NumThreads} threads)"
	${WD}/stdwrap.sh ${STRINGTIE} \
		-p ${NumThreads} \
		-G ${GTF} \
		-o stringtie/transcript.gtf \
		-A stringtie/gene.tsv \
		-C stringtie/transcript_covered.gtf \
		${StringTieOptions} \
		bam/alignment.bam \
		> stringtie/stringtie.out
	touch "done/stringtie.done"
fi

if [ ! -f "done/prepde.done" ]; then
	rg_progress 90 "Running prepDE"
	echo "${ExternalStringTieName} ./stringtie/transcript.gtf" > input.lst
	${PREPDE} \
		-i input.lst \
		-l ${AvgReadLength} \
		-g stringtie/gene_count.csv \
		-t stringtie/transcript_count.csv \
		> stringtie/prepde.out
	touch "done/prepde.done"
fi

rg_progress 95 "Copying result files to project archive"
mkdir -p ${StringTieFolder}
rm -rf ${StringTieFolder}/*
cp stringtie/* ${StringTieFolder}
ls -1 ${StringTieFolder}/* >> ${WD}/files.out

rg_progress 99 "Analysis completed, cleaning up..."
